Installation
============


Install with ``pip``
--------------------

.. code:: 

    $ pip install Products.LocalFS


Install with ``zc.buildout``
----------------------------
Just add :mod:`Products.LocalFS` to the ``eggs`` setting(s) in your
buildout configuration to have it pulled in automatically::

    ...
    eggs =
        Products.LocalFS
    ...
